@@ -5,7 +5,7 @@ from typing import Annotated
 
 import typer
 
-from ..constants import SYSTEM_PAGE_SIZE
+from ..constants import DEFAULT_ASSEMBLY, SYSTEM_PAGE_SIZE
 from ..variants import getter, search
 
 variant_app = typer.Typer(help="Search and get variants from MyVariant.info.")
@@ -35,6 +35,14 @@ def get_variant(
             help="Include annotations from external sources (TCGA, 1000 Genomes, cBioPortal)",
         ),
     ] = True,
+    assembly: Annotated[
+        str,
+        typer.Option(
+            "--assembly",
+            help="Genome assembly (hg19 or hg38)",
+            case_sensitive=False,
+        ),
+    ] = DEFAULT_ASSEMBLY,
 ):
     """
     Get detailed information about a specific genetic variant.
@@ -46,16 +54,26 @@ def get_variant(
         Get by rsID: biomcp variant get rs113488022
         Get as JSON: biomcp variant get rs113488022 --json
         Get without external annotations: biomcp variant get rs113488022 --no-external
+        Get with hg38 assembly: biomcp variant get rs113488022 --assembly hg38
     """
     if not variant_id:
         typer.echo("Error: A variant identifier must be provided.", err=True)
         raise typer.Exit(code=1)
 
+    # Validate assembly value
+    if assembly not in ["hg19", "hg38"]:
+        typer.echo(
+            f"Error: Invalid assembly '{assembly}'. Must be 'hg19' or 'hg38'.",
+            err=True,
+        )
+        raise typer.Exit(code=1)
+
     result = asyncio.run(
         getter.get_variant(
             variant_id,
             output_json=output_json,
             include_external=include_external,
+            assembly=assembly,
         )
     )
     typer.echo(result)
@@ -193,3 +211,96 @@ def search_variant_cmd(
 
     result = asyncio.run(search.search_variants(query, output_json))
     typer.echo(result)
+
+
+@variant_app.command("predict")
+def predict_variant_effects(
+    chromosome: Annotated[
+        str,
+        typer.Argument(help="Chromosome (e.g., chr7, chrX)"),
+    ],
+    position: Annotated[
+        int,
+        typer.Argument(help="1-based genomic position"),
+    ],
+    reference: Annotated[
+        str,
+        typer.Argument(help="Reference allele(s) (e.g., A, ATG)"),
+    ],
+    alternate: Annotated[
+        str,
+        typer.Argument(help="Alternate allele(s) (e.g., T, A)"),
+    ],
+    interval_size: Annotated[
+        int,
+        typer.Option(
+            "--interval",
+            "-i",
+            help="Analysis interval size in bp (max 1000000)",
+            min=2000,
+            max=1000000,
+        ),
+    ] = 131072,
+    tissue: Annotated[
+        list[str] | None,
+        typer.Option(
+            "--tissue",
+            "-t",
+            help="UBERON ontology terms for tissue-specific predictions",
+        ),
+    ] = None,
+    threshold: Annotated[
+        float,
+        typer.Option(
+            "--threshold",
+            help="Significance threshold for log2 fold changes",
+            min=0.0,
+            max=5.0,
+        ),
+    ] = 0.5,
+    api_key: Annotated[
+        str | None,
+        typer.Option(
+            "--api-key",
+            help="AlphaGenome API key (overrides ALPHAGENOME_API_KEY env var)",
+            envvar="ALPHAGENOME_API_KEY",
+        ),
+    ] = None,
+):
+    """
+    Predict variant effects using Google DeepMind's AlphaGenome:\n
+    - Gene expression changes\n
+    - Chromatin accessibility\n
+    - Splicing alterations\n
+    - Promoter activity\n
+    \n
+    Requires AlphaGenome API key via --api-key or ALPHAGENOME_API_KEY env var.\n
+    \n
+    Examples:
+    \n\t# Predict BRAF V600E mutation
+    \n\tbiomcp variant predict chr7 140753336 A T
+    \n
+    \n\t# With API key specified
+    \n\tbiomcp variant predict chr7 140753336 A T --api-key YOUR_KEY
+    \n
+    \n\t# With tissue-specific predictions
+    \n\tbiomcp variant predict chr7 140753336 A T --tissue UBERON:0002367
+    \n
+    \n\t# With larger analysis interval
+    \n\tbiomcp variant predict chr7 140753336 A T --interval 500000
+    """
+    from ..variants.alphagenome import predict_variant_effects
+
+    result = asyncio.run(
+        predict_variant_effects(
+            chromosome=chromosome,
+            position=position,
+            reference=reference,
+            alternate=alternate,
+            interval_size=interval_size,
+            tissue_types=tissue,
+            significance_threshold=threshold,
+            api_key=api_key,
+        )
+    )
+    typer.echo(result)
