@@ -21,6 +21,16 @@ PUBTATOR3_AUTOCOMPLETE_URL = f"{PUBTATOR3_BASE_URL}/entity/autocomplete/"
 CLINICAL_TRIALS_BASE_URL = "https://clinicaltrials.gov/api/v2/studies"
 CLINICAL_TRIALS_STUDY_URL = "https://clinicaltrials.gov/study/"
 
+# NCI Clinical Trials Search API
+# https://clinicaltrialsapi.cancer.gov/api/v2
+NCI_CTS_BASE_URL = "https://clinicaltrialsapi.cancer.gov/api/v2"
+NCI_TRIALS_URL = f"{NCI_CTS_BASE_URL}/trials"
+NCI_ORGANIZATIONS_URL = f"{NCI_CTS_BASE_URL}/organizations"
+NCI_DISEASES_URL = f"{NCI_CTS_BASE_URL}/diseases"
+NCI_INTERVENTIONS_URL = f"{NCI_CTS_BASE_URL}/interventions"
+NCI_BIOMARKERS_URL = f"{NCI_CTS_BASE_URL}/biomarkers"
+NCI_API_KEY_ENV = "NCI_API_KEY"
+
 # MyVariant.info API
 # https://docs.myvariant.info/
 MYVARIANT_BASE_URL = "https://myvariant.info/v1"
@@ -64,7 +74,9 @@ UCSC_GENOME_BROWSER_URL = "https://genome.ucsc.edu/cgi-bin/hgTracks?db=hg19&"
 DEFAULT_CACHE_TIMEOUT = 60 * 60 * 24 * 7  # 1 week in seconds
 
 # Pagination
-SYSTEM_PAGE_SIZE = 40  # Default page size for all searches
+SYSTEM_PAGE_SIZE = (
+    10  # Default page size for all searches (reduced for token efficiency)
+)
 DEFAULT_PAGE_SIZE = 10  # Default page size for unified search
 MIN_PAGE_SIZE = 1
 MAX_PAGE_SIZE = 100
@@ -84,6 +96,9 @@ MAX_AUTOCOMPLETE_LIMIT = 100
 MAX_WIDTH = 72  # Maximum width for text wrapping in console output
 SNIPPET_LENGTH = 200  # Maximum length for text snippets in search results
 
+# Genome Assembly
+DEFAULT_ASSEMBLY = "hg19"  # Default genome assembly for MyVariant.info API
+
 # Rate Limiting
 DEFAULT_RATE_LIMIT_PER_SECOND = 10.0
 DEFAULT_BURST_SIZE = 20
@@ -116,25 +131,113 @@ HTTP_TIMEOUT_SECONDS = 120.0
 HTTP_ERROR_CODE_NETWORK = 599
 HTTP_ERROR_CODE_UNSUPPORTED_METHOD = 405
 
+# Batching and Pagination Configuration
+DEFAULT_BATCH_SIZE = 10
+DEFAULT_BATCH_TIMEOUT = 0.1
+CBIOPORTAL_BATCH_SIZE = 5
+EUROPE_PMC_PAGE_SIZE = 25
+BIORXIV_MAX_PAGES = 3
+BIORXIV_RESULTS_PER_PAGE = 30
+BIORXIV_DEFAULT_DAYS_BACK = 365
+
+# Prefetching Configuration
+PREFETCH_TOP_GENES = 5
+PREFETCH_TOP_DISEASES = 3
+PREFETCH_TOP_CHEMICALS = 3
+PREFETCH_TIMEOUT = 2.0
+
+# Cache Configuration
+REQUEST_CACHE_MAX_SIZE = 1000
+CACHE_KEY_SAMPLE_SIZE = 100
+
+# Connection Pool Configuration
+CONNECTION_POOL_MAX_KEEPALIVE = 20
+CONNECTION_POOL_MAX_CONNECTIONS = 100
+CONNECTION_POOL_KEEPALIVE_EXPIRY = 30
+
 # ============================================================================
 # Domain Configuration
 # ============================================================================
 
 # Valid domains for search
-VALID_DOMAINS = ["article", "trial", "variant"]
-VALID_DOMAINS_PLURAL = ["articles", "trials", "variants"]
+VALID_DOMAINS = [
+    "article",
+    "trial",
+    "variant",
+    "gene",
+    "drug",
+    "disease",
+    "nci_organization",
+    "nci_intervention",
+    "nci_biomarker",
+    "nci_disease",
+    # OpenFDA domains
+    "fda_adverse",
+    "fda_label",
+    "fda_device",
+    "fda_approval",
+    "fda_recall",
+    "fda_shortage",
+]
+VALID_DOMAINS_PLURAL = [
+    "articles",
+    "trials",
+    "variants",
+    "genes",
+    "drugs",
+    "diseases",
+    "nci_organizations",
+    "nci_interventions",
+    "nci_biomarkers",
+    "nci_diseases",
+    # OpenFDA domains
+    "fda_adverse_events",
+    "fda_labels",
+    "fda_device_events",
+    "fda_approvals",
+    "fda_recalls",
+    "fda_shortages",
+]
 
 # Domain mappings for unified search
 DOMAIN_TO_PLURAL = {
     "article": "articles",
     "trial": "trials",
     "variant": "variants",
+    "gene": "genes",
+    "drug": "drugs",
+    "disease": "diseases",
+    "nci_organization": "nci_organizations",
+    "nci_intervention": "nci_interventions",
+    "nci_biomarker": "nci_biomarkers",
+    "nci_disease": "nci_diseases",
+    # OpenFDA domains
+    "fda_adverse": "fda_adverse_events",
+    "fda_label": "fda_labels",
+    "fda_device": "fda_device_events",
+    "fda_approval": "fda_approvals",
+    "fda_recall": "fda_recalls",
+    "fda_shortage": "fda_shortages",
 }
 
 PLURAL_TO_DOMAIN = {
     "articles": "article",
     "trials": "trial",
     "variants": "variant",
+    "genes": "gene",
+    "drugs": "drug",
+    "diseases": "disease",
+    "nci_organizations": "nci_organization",
+    "nci_interventions": "nci_intervention",
+    "nci_biomarkers": "nci_biomarker",
+    "nci_diseases": "nci_disease",
+    # OpenFDA domains
+    "fda_adverse_events": "fda_adverse",
+    "fda_labels": "fda_label",
+    "fda_device_events": "fda_device",
+    "fda_approvals": "fda_approval",
+    "fda_recalls": "fda_recall",
+    "fda_shortages": "fda_shortage",
 }
 
 # Trial detail sections
